multivariateLassosum-package: LASSO with summary statistics and a reference panel for...

multivariateLassosum-packageR Documentation

LASSO with summary statistics and a reference panel for multiple phenotypes

Description

Performs polygenic risk score estimation for multiple phenotypes simultaneously with a LASSO penalized mixed model, which uses summary statistics and a reference panel of genotypes.

Package Content

Index: This package was not yet installed at build time.

Maintainer

Alexandre Bureau <alexandre.bureau@fmed.ulaval.ca>

Author(s)

Alexandre Bureau, Meriem Bahda


MeriemBahda/LassosumExtension documentation built on May 16, 2024, 3:10 p.m.