| multivariateLassosum-package | R Documentation |
Performs polygenic risk score estimation for multiple phenotypes simultaneously with a LASSO penalized mixed model, which uses summary statistics and a reference panel of genotypes.
Index: This package was not yet installed at build time.
Alexandre Bureau <alexandre.bureau@fmed.ulaval.ca>
Alexandre Bureau, Meriem Bahda
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.